import React from "react";
import { NavigationContainer } from "@react-navigation/native";
import { CardStyleInterpolators, createStackNavigator } from '@react-navigation/stack'
import { createBottomTabNavigator } from "@react-navigation/bottom-tabs";
import NearYouScreen from "./screens/NearYouScreen";
import NetworkScreen from "./screens/NetworkScreen";
import SelfProfileScreen from "./screens/SelfProfileScreen";
import OtherProfileScreen from "./screens/OtherProfileScreen";
import MessagingScreen from "./screens/MessagingScreen";
import CollisionScreen from "./screens/CollisionScreen";
import AddToNetworkScreen from "./screens/AddToNetworkScreen";
import CollisionLocationSharingScreen from "./screens/CollisionLocationSharingScreen";
import MenuBar from "./components/MenuBar";
import AppLoading from 'expo-app-loading';
import {
    useFonts,
    DMSans_400Regular,
    DMSans_400Regular_Italic,
    DMSans_500Medium,
    DMSans_500Medium_Italic,
    DMSans_700Bold,
    DMSans_700Bold_Italic
} from '@expo-google-fonts/dm-sans';
import { Platform } from "react-native";
import * as TaskManager from "expo-task-manager";

const Stack = createStackNavigator();
const Tab = createBottomTabNavigator();

TaskManager.defineTask("Background Location", ({data, error}) => {
    if (error) {
        console.log(error);
    }
    if (data) {
        console.log(data);
    }
})

const App = () => {
    const [fontsLoaded] = useFonts({
        DMSans_400Regular,
        DMSans_400Regular_Italic,
        DMSans_500Medium,
        DMSans_500Medium_Italic,
        DMSans_700Bold,
        DMSans_700Bold_Italic
    });

    if (!fontsLoaded) {
        return (
            <AppLoading />
        );
    }

    return (
        <NavigationContainer>
            <Stack.Navigator
                initialRouteName="Tab Navigator"
                screenOptions={{ headerShown: false }}
            >
                <Stack.Screen
                    name="Tab Navigator"
                    component={TabNavigator}
                />
                <Stack.Group
                    screenOptions={{
                        cardStyleInterpolator: Platform.OS == "android" ? CardStyleInterpolators.forRevealFromBottomAndroid : CardStyleInterpolators.forVerticalIOS,
                        gestureEnabled: false
                    }}
                >
                    <Stack.Screen
                        name="Collision Screen"
                        component={CollisionScreen}
                    />
                </Stack.Group>
                <Stack.Screen
                    name="Collision Location Sharing Screen"
                    component={CollisionLocationSharingScreen}
                />
                <Stack.Screen
                    name="Other's Profile Screen"
                    component={OtherProfileScreen}
                />
                <Stack.Screen
                    name="Messaging Screen"
                    component={MessagingScreen}
                />
                <Stack.Screen
                    name="Add to Network"
                    component={AddToNetworkScreen}
                />
            </Stack.Navigator>
        </NavigationContainer>
    );
};

const TabNavigator = () => {
    return (
        <Tab.Navigator
            initialRouteName="Near You"
            screenOptions={{ headerShown: false }}
            tabBar={(props) => <MenuBar {...props} />}
        >
            <Tab.Screen
                name="Near You"
                component={NearYouScreen}
            />
            <Tab.Screen
                name="Network"
                component={NetworkScreen}
            />
            <Tab.Screen
                name="Profile"
                component={SelfProfileScreen}
            />
        </Tab.Navigator>
    );
};

export default App;

/**
 * Polyfill for Promise.allSettled since React Native apparently doesn't implement it itself on all
 * versions (including mine) :(
 * @param {Iterable<Promise>} values An array of promises.
 */
const allSettledPolyfill = function(values) {
    const promises = Array.from(values);

    if (promises.length == 0) return Promise.resolve([]);

    return Promise.all(promises.map(promise => new Promise(function(resolve) {
        promise.then(
            value => resolve({status: "fulfilled", value}),
            reason => resolve({status: "reject", reason})
        );
    })));
};
Promise.allSettled = Promise.allSettled || allSettledPolyfill;
