import React from 'react';
import { View, Pressable, StyleSheet, Alert } from 'react-native';
import usePaddedSafeAreaInsets from '../scripts/usePaddedSafeAreaInsets';
import useColors from '../scripts/useColors';
import { useNavigation } from '@react-navigation/native';
import StatusIndicator from './StatusIndicator';
import Icon from './Icon';

export const HeaderBar = (props) => {
    const insets = usePaddedSafeAreaInsets();
    const colors = useColors();

    const navigation = useNavigation();

    return (
        <View style={{
            width: "100%",
            borderBottomColor: colors.TEXT,
            borderBottomWidth: StyleSheet.hairlineWidth,
            paddingTop: insets.top,
            paddingLeft: insets.left,
            paddingRight: insets.right,
            backgroundColor: colors.BACKGROUND,
            alignItems: "center",
            display: "flex",
            flexDirection: "row",
            justifyContent: "space-between",
            alignItems: "stretch",
        }}>
            <StatusIndicator/>
            <Pressable
                style={{
                    aspectRatio: 5/3,
                    alignItems: "center",
                    justifyContent: "center",
                    alignSelf: "center",
                    height: 60
                }}
                onPressIn={e =>
                    navigation.navigate("Near You")
                }
            >
                <Icon height={40}>logo</Icon>
            </Pressable>
            <Pressable
                style={{
                    aspectRatio: 1/1,
                    justifyContent: "center",
                    alignItems: "center"
                }}
                onPress={e =>
                    Alert.alert(
                        ":(",
                        "Sorry, this part of the app hasn't been implemented for the prototype.",
                        [
                            {
                                text: "Okay",
                                style: "cancel"
                            }
                        ],
                        {
                            cancelable: true
                        }
                    )
                }
            >
                <Icon color={colors.TEXT}>chat</Icon>
            </Pressable>
        </View>
    )
};

export default HeaderBar;