import React from 'react';
import { View, Pressable, StyleSheet, Image } from 'react-native';
import usePaddedSafeAreaInsets from '../scripts/usePaddedSafeAreaInsets';
import Icon from './Icon';
import { selfUser } from  "./../scripts/hardcoded_data"
import useColors from '../scripts/useColors';

export const MenuBar = (props) => {
    const insets = usePaddedSafeAreaInsets();
    const selectedTab = props.state.routes[props.state.index].name.toLowerCase()
    const colors = useColors();

    const pressableStyle = {
        flexGrow: 1,
        alignItems: "center",
        justifyContent: "center",
        padding: 15
    };

    return (
        <View style={{
            width: "100%",
            borderTopColor: colors.TEXT,
            borderTopWidth: StyleSheet.hairlineWidth,
            paddingBottom: insets.bottom,
            backgroundColor: colors.BACKGROUND
        }}>
            <View style={{
                width: "100%",
                display: "flex",
                flexDirection: "row"
            }}>
                <Pressable
                    style={[
                        pressableStyle,
                        {paddingLeft: insets.left}
                    ]}
                    onPressIn={e =>
                        props.navigation.navigate("Near You")
                    }
                >
                    {
                        selectedTab == "near you" ?
                        <Icon color={colors.TEXT} height={35}>ant-design:compass-filled</Icon> :
                        <Icon color={colors.TEXT} height={35}>ant-design:compass-outline</Icon>
                    }
                </Pressable>
                <Pressable
                    style={pressableStyle}
                    onPressIn={e =>
                        props.navigation.navigate("Network")
                    }
                >
                    {
                        selectedTab == "network" ?
                        <Icon color={colors.TEXT} height={35}>bxs:network-chart</Icon> :
                        <Icon color={colors.TEXT} height={35}>bx:network-chart</Icon>
                    }
                </Pressable>
                <Pressable
                    style={[
                        pressableStyle,
                        {paddingRight: insets.right}
                    ]}
                    onPressIn={e =>
                        props.navigation.navigate("Profile")
                    }
                >
                    <View
                        style={{
                            borderRadius: "50%",
                            height: 32,
                            width: 32,
                            borderWidth: 3,
                            borderColor: selectedTab == "profile" ? colors.TEXT : "transparent",
                            padding: 1
                        }}
                    >
                        <Image
                            source={{
                                uri: selfUser.profileImage
                            }}
                            style={{
                                borderRadius: 9999,
                                height: "100%",
                                width: "100%"
                            }}
                        />
                    </View>
                </Pressable>
            </View>
        </View>
    )
};

export default MenuBar;