import React, { useCallback, useState } from 'react';
import {View, TouchableOpacity } from 'react-native';
import StyledText from './StyledText';
import useColors from "../scripts/useColors";
import { selfUser } from "../scripts/hardcoded_data";
import GlobalEvents from '../scripts/GlobalEvents';

/**
 * @param {object} props
 */
 const StatusIndicator = ({...props}) => {
    const [isActive, setIsActive] = useState(selfUser.isActive);
    const colors = useColors();

    // Whenever we toggle status, rerender all instances of status bar
    GlobalEvents.useListener("statusupdate", (isActive) => {
        setIsActive(isActive);
    }, []);

    const onPress = useCallback(() => {
        const status = !isActive;
        selfUser.isActive = status;
        // Emit to all instances of status bar to toggle
        GlobalEvents.emit("statusupdate", status);
    }, [isActive]);

    return (
        <TouchableOpacity
            style={{
                aspectRatio: 1/1,
                display: "flex",
                flexDirection: "column",
                alignItems: "center",
                justifyContent: "center"
            }}
            onPress={onPress}
        >
            <View style={{
                aspectRatio: 1/1,
                height: 12,
                borderRadius: 12 / 2,
                backgroundColor: isActive ? colors.COLOR_SCHEME == "light" ? "green" : "lime" : colors.SECONDARY_TEXT
            }}/>
            <StyledText style={{ fontSize: 14 }}>{isActive ? "Active" : "Away"}</StyledText>
        </TouchableOpacity>
    )
};

export default StatusIndicator; 