import { useNavigation } from "@react-navigation/native";
import React from "react";
import { View, TouchableOpacity,StyleSheet, ScrollView } from "react-native";
import Icon from '../components/Icon';
import StyledText from "../components/StyledText";
import { style_values } from "../scripts/styles";
import SearchBar from "../components/SearchBar";
import useColors from "../scripts/useColors";
import usePaddedSafeAreaInsets from "../scripts/usePaddedSafeAreaInsets";
import FriendSuggestion from "../components/FriendSuggestion";
import { user_pool } from "../scripts/hardcoded_data";


const AddToNetworkScreen = (props) => {
    const colors = useColors();

    let suggestions = [];
    //adding Ekin, who is user -4
    suggestions.push(
        <React.Fragment key={-4}>
            <FriendSuggestion name={user_pool[-4].firstName + " " + user_pool[-4].lastName} imagePath={user_pool[-4].profileImage} userID={user_pool[-4].id}/>
        </React.Fragment>
    );

    for (let i = 38; i < 41; i++) {
        suggestions.push(
            <React.Fragment key={i}>
                <FriendSuggestion name={user_pool[i].firstName + " " + user_pool[i].lastName} imagePath={user_pool[i].profileImage} userID={user_pool[i].id}/>
            </React.Fragment>);
    }

    let recents = [];
    for (let i = 41; i < 44; i++) {
        recents.push(
            <React.Fragment key={i}>
                <FriendSuggestion name={user_pool[i].firstName + " " + user_pool[i].lastName} imagePath={user_pool[i].profileImage} userID={user_pool[i].id}/>
            </React.Fragment>);
    }

    return (
        <View
            style={{
                display: "flex",
                flexDirection: "column",
                height: "100%",
                backgroundColor: colors.BACKGROUND,
            }}
        >
            <BackHeader title={"Add a Friend"} />
            <View style={styles.searchContainer}>
                <SearchBar
                    placeholder="Search"
                    autoCapitalize="words"
                    autoCorrect={false}
                    style={styles.search}
                />
            </View>
            <View
                style={{
                    backgroundColor: colors.BACKGROUND,
                    paddingTop: style_values.screen_padding.vertical,
                    paddingBottom: style_values.screen_padding.vertical,
                    flexGrow: 1
                }}
            >
                <StyledText type="h2" style={styles.title}>Suggestions</StyledText>
                <View style={styles.scrollContainer}>
                    <ScrollView horizontal={true}
                        showsHorizontalScrollIndicator={false}>
                        <View style={styles.carouselView}>
                            {suggestions}
                        </View>
                    </ScrollView></View>
                <StyledText type="h2" style={styles.title}>Recent Collisions</StyledText>
                <View style={styles.scrollContainer}>
                    <ScrollView horizontal={true}
                        showsHorizontalScrollIndicator={false}>
                        <View style={styles.carouselView}>
                            {recents}
                        </View>
                    </ScrollView></View>
            </View>
        </View>
    );
};

const styles = StyleSheet.create({
    title: {
        fontFamily: "DMSans_500Medium",
        fontSize: 16,
        marginLeft: 10
    },
    scrollContainer: {
        maxHeight: 355,
        marginTop: 10,
        marginBottom: 20,
    },
    carouselView: {
        flexDirection: 'row',
        paddingHorizontal: 5
    },
    searchContainer: {
        paddingTop: 10,
        paddingHorizontal: 10
    }

})

const BackHeader = ({ title }) => {
    const colors = useColors();
    const navigation = useNavigation();
    const insets = usePaddedSafeAreaInsets();

    return (
        <View style={{
            display: "flex",
            flexDirection: "row",
            paddingLeft: insets.left,
            paddingRight: insets.right,
            paddingTop: insets.top,
            paddingBottom: style_values.screen_padding.vertical,
            borderBottomColor: colors.SECONDARY_TEXT,
            borderBottomWidth: StyleSheet.hairlineWidth,
        }}>
            <TouchableOpacity
                style={{
                    display: "flex",
                    flexDirection: "row",
                    alignItems: "center"
                }}
                onPress={e => navigation.goBack()}
            >
                <Icon
                    height={28}
                    color={colors.TEXT}
                >chevron-left</Icon>
                <StyledText style={{ fontSize: 28, fontWeight: 500, marginLeft: 29 * .35 }}>{title}</StyledText>
            </TouchableOpacity>
        </View>
    );
}

export default AddToNetworkScreen;