import React, { useCallback } from "react";
import { View, ScrollView, Image, StyleSheet, Pressable, Alert } from "react-native";
import { LinearGradient } from "expo-linear-gradient";
import useColors from "../scripts/useColors";
import StyledText from "../components/StyledText";
import usePaddedSafeAreaInsets from '../scripts/usePaddedSafeAreaInsets';
import { selfUser, user_pool, matchScores, networkRequestsSent, network_connections, __PROTOTYPE__TASK3_USER_ID } from "../scripts/hardcoded_data";
import BackBtn from "../components/BackBtn";
import Icon from "../components/Icon";
import { style_values } from "../scripts/styles";
import Color from "color";
import { BlurView } from "expo-blur"
import { StatusBar } from "expo-status-bar";
import RowButton from "../components/RowButton";
import useTriggerRerender from "../scripts/useTriggerRerender";
import GlobalEvents from "../scripts/GlobalEvents";
import MaskedView from '@react-native-masked-view/masked-view';

const OtherProfileScreen = (props) => {
    const insets = usePaddedSafeAreaInsets();
    const colors = useColors();
    const triggerRerender = useTriggerRerender();

    const userID = props.route.params.userID;
    const distance = props.route.params.distance;
    const user = user_pool[userID];

    // Get the user's first name.
    const name = user.firstName;

    // Calculate the age from the user's birth date.
    const now = new Date();
    let age = now.getFullYear() - user.birthDate.getFullYear();
    now.setFullYear(user.birthDate.getFullYear());
    age -= now < user.birthDate ? 1 : 0;

    // Calculate how many mutual friends the self user shares with this user.
    const mutuals = (() => {
        const setA = new Set(selfUser.friends.length < user.friends.length ? selfUser.friends : user.friends);
        const setB = new Set(selfUser.friends.length < user.friends.length ? user.friends : selfUser.friends);

        for (const ID of setA) {
            if (setB.has(ID)) continue;
            setA.delete(ID);
        }

        return setA.size;
    })();

    // Check if this user is already in our network.
    const inNetwork = selfUser.friends.includes(userID);
    const requested = !inNetwork && networkRequestsSent.has(userID);

    // This connectionchange listener will cause the component to re-render every time it detects
    // that this person has been either added or removed from our network.
    GlobalEvents.useListener("connectionchange", ({added, removed}) => {
        if (inNetwork) {
            for (const ID of removed) {
                if (ID == userID) {
                    const index = selfUser.friends.indexOf(userID);
                    if (!index) selfUser.friends.splice(index, 1);
                    triggerRerender();
                    break;
                }
            }
        } else {
            for (const ID of added) {
                if (ID == userID) {
                    if (!selfUser.friends.includes(userID)) selfUser.friends.push(userID);
                    triggerRerender();
                    break;
                }
            }
        }
    }, [inNetwork]);

    const Styles = {
        matchButton: {position: 'absolute', right: style_values.screen_padding.horizontal, bottom: style_values.screen_padding.vertical, borderRadius: "50%", overflow: "hidden"},
        nameAgeMutalsContainer: {display: 'flex', flexDirection: 'row', marginTop: 10, justifyContent: "space-between", alignItems: "center"},
        mutuals: {fontWeight: 500, color: colors.FLAT2, fontSize: 18},
        pronounsContainer: {display: 'flex', flexDirection: 'row', marginBottom: 15},
        milesAwayContainer: {display: 'flex', flexDirection: 'row', alignItems: "center"},
        milesAway: {color: colors.SECONDARY_TEXT, fontSize: 18, fontWeight: 500, marginLeft: 18*.35},
        addToNetworkContainer: {display: "flex", flexDirection: "row", alignItems: "stretch", justifyContent: "center", paddingBottom: insets.bottom, paddingLeft: insets.left, paddingRight: insets.right, borderTopWidth: StyleSheet.hairlineWidth, borderTopColor: colors.SECONDARY_TEXT, paddingTop: style_values.screen_padding.vertical},
    }

    const removeFromNetwork = useCallback(() => {
        let index = selfUser.friends.indexOf(userID);
        if (~index) selfUser.friends.splice(index, 1);
        index = user_pool[userID].friends.indexOf(selfUser.id);
        if (~index) user_pool[userID].friends.splice(index, 1);
        for (let i = 0; i < network_connections.length; i++) {
            if (network_connections[i].id == userID) {
                network_connections.splice(i, 1);
                break;
            }
        }

        GlobalEvents.emit("connectionchange", {
            removed: new Set([userID]),
            added: new Set()
        });
    }, []);

    return (
        <View style={{display: "flex", flexGrow: 1, backgroundColor: colors.BACKGROUND, height: "100%"}}>
            <StatusBar style={colors.COLOR_SCHEME == "light" ? "dark" : "light"}/>
            <BackBtn
                style={{
                    top: insets.top + style_values.screen_padding.vertical
                }}
            />
            <LinearGradient
                style={{
                    position: "absolute",
                    top: 0,
                    left: 0,
                    height: insets.top + 10,
                    width: "100%",
                    zIndex: 1,
                    opacity: .65
                }}
                colors={[
                    colors.BACKGROUND + "FF",
                    colors.BACKGROUND + "C0",
                    colors.BACKGROUND + "00"
                ]}
                locations={[
                    0,
                    0.6,
                    1
                ]}
            />
            <ScrollView style={{flexGrow: 1, flexShrink: 1}}>
                <View style={{display: "flex", flexDirection: "column"}}>
                    <View style={{marginTop: insets.top, aspectRatio: 1/1, width: "100%"}}/>
                    <Image
                        style={{
                            position: "absolute",
                            left: 0,
                            top: 0,
                            height: "100%",
                            width: "100%",
                            borderBottomLeftRadius: style_values.border_radius * 2,
                            borderBottomRightRadius: style_values.border_radius * 2,
                            zIndex: 0
                        }}
                        resizeMode="cover"
                        source={{
                            uri: user.profileImage
                        }}
                    />
                    <View style={Styles.matchButton}>
                        <BlurView
                            tint={colors.COLOR_SCHEME}
                            intensity={65}
                            style={{paddingHorizontal: 25, paddingVertical: 10}}
                        >
                            <StyledText style={{fontWeight: 500}}>{Math.floor(matchScores[userID] * 100)}% Match</StyledText>
                        </BlurView>
                    </View>
                </View>
                <View style={{
                    paddingLeft: insets.left,
                    paddingRight: insets.right,
                    paddingBottom: style_values.screen_padding.vertical,
                    display: "flex",
                    flexDirection: "column",
                    alignItems: "stretch"
                }}>
                    <View>
                        <View style={Styles.nameAgeMutalsContainer}>
                            <StyledText type="title">{user.firstName}, {age}</StyledText>
                            <StyledText style={Styles.mutuals}>{mutuals} mutual{mutuals.length == 1 ? "" : "s"}</StyledText>
                        </View>
                        <View style={Styles.pronounsContainer}>
                            <StyledText type="secondary">{user.pronouns}</StyledText>
                        </View>
                        {
                            typeof distance == "string" ?
                            <View style={Styles.milesAwayContainer}>
                                <Icon height={18} color={colors.SECONDARY_TEXT}>location-pin</Icon>
                                <StyledText style={Styles.milesAway}>{distance} away</StyledText>
                            </View> :
                            null
                        }
                    </View>
                    <View style={{marginTop: 20}}>
                        <StyledText type="h3">Similar:</StyledText>
                        <View style={{display: "flex", flexDirection: "row", flexWrap: "wrap"}}>
                            <InterestBubble isSimilarInterest={true}>💻 CS</InterestBubble>
                            <InterestBubble isSimilarInterest={true}>🍳 Cooking</InterestBubble>
                            <InterestBubble isSimilarInterest={true}>🚀 Entrepreneurship</InterestBubble>
                            <InterestBubble isSimilarInterest={true}>🌲 Stanford</InterestBubble>
                            <InterestBubble isSimilarInterest={true}>🏀 Basketball</InterestBubble>
                        </View>
                    </View>
                    <View style={{marginTop: 20}}>
                        <StyledText type="h3">Others:</StyledText>
                        <View style={{display: 'flex', flexDirection: 'row', flexWrap: "wrap"}}>
                            <InterestBubble isSimilarInterest={false}>📷 Photography</InterestBubble>
                            <InterestBubble isSimilarInterest={false}>☄ Astronomy</InterestBubble>
                            <InterestBubble isSimilarInterest={false}>🎨 Graphic Design</InterestBubble>
                            <InterestBubble isSimilarInterest={false}>🤖 AI</InterestBubble>
                        </View>
                    </View>
                </View>
            </ScrollView>
            <View style={Styles.addToNetworkContainer}>
                {
                    inNetwork ?
                    <RowButton
                        destructive
                        mainAction
                        onPress={e => {
                            Alert.alert(
                                `Remove ${name}?`,
                                `Are you sure you want to remove ${name} from your friend network? You'll have to send another friend request to undo this.`,
                                [
                                    {
                                        text: "Remove",
                                        style: "destructive",
                                        onPress: removeFromNetwork
                                    },
                                    {
                                        text: "Cancel",
                                        style: "cancel"
                                    }
                                ],
                                {
                                    cancelable: false
                                }
                            )
                            triggerRerender();
                        }}
                    >Remove Friend</RowButton> :
                    requested ?
                    <RowButton
                        onPress={e => {
                            // This part is included ONLY for the prototype, until a real backend is
                            // implemented. It checks if this is the user for task #3, and simulates
                            // that user accepting the network request after a few seconds.
                            if (userID == __PROTOTYPE__TASK3_USER_ID) {
                                __PROTOTYPE__cancelRequestToEkin();
                            }

                            networkRequestsSent.delete(userID);
                            triggerRerender();
                        }}
                    >Request Sent</RowButton> :
                    <RowButton
                        mainAction
                        onPress={e => {
                            // This part is included ONLY for the prototype, until a real backend is
                            // implemented. It checks if this is the user for task #3, and simulates
                            // that user accepting the network request after a few seconds.
                            if (userID == __PROTOTYPE__TASK3_USER_ID) {
                                __PROTOTYPE__sendRequestToEkin();
                            }

                            networkRequestsSent.add(userID);
                            triggerRerender();
                        }}
                    >Send Friend Request</RowButton>
                }
                <Pressable
                    onPress={e => {
                        props.navigation.navigate('Messaging Screen', {userID, name: name});
                    }}
                >
                    <MaskedView
                        style={{
                            aspectRatio: 1/1,
                            height: 52,
                            marginLeft: style_values.screen_padding.horizontal
                        }}
                        maskElement={
                            <View
                                style={{
                                    height: "100%",
                                    width: "100%",
                                    borderRadius: "50%",
                                    borderWidth: 2.5,
                                    borderColor: "black",
                                    alignItems: "center",
                                    justifyContent: "center",
                                    padding: 10
                                }}
                            >
                                <Icon height={32}>chat</Icon>
                            </View>
                        }
                    >
                        <LinearGradient
                            style={{
                                height: "100%",
                                width: "100%"
                            }}
                            colors={[colors.FLAT1, colors.FLAT2]}
                        />
                    </MaskedView>
                </Pressable>
            </View>
        </View>
    );
};

/**
 * @param {object} props
 * @param {boolean} props.isSimilarInterest
 */
const InterestBubble = ({isSimilarInterest, ...props}) => {
    const colors = useColors();
    const backgroundColor = isSimilarInterest ? Color(colors.FLAT1).mix(Color(colors.BACKGROUND), 0.8).hex() : Color(colors.FLAT2).mix(Color(colors.BACKGROUND), 0.8).hex();

    return (
        <View style={{
            backgroundColor,
            borderRadius: "50%",
            alignItems: "center",
            paddingHorizontal: 25,
            paddingVertical: 10,
            marginTop: 6,
            marginRight: 8
        }} >
            <StyledText style={{fontSize: 16, fontWeight: 500}}>{props.children}</StyledText>
        </View>
    );
};

export default OtherProfileScreen;



// This part is included ONLY for the prototype, until a real backend is implemented. It simulates
// the user accepting a friend request for Task #3 6 seconds after requesting.
let __PROTOTYPE__ekinRequestInterval = null;
const __PROTOTYPE__sendRequestToEkin = () => {
    __PROTOTYPE__ekinRequestInterval = setTimeout(function() {
        networkRequestsSent.delete(__PROTOTYPE__TASK3_USER_ID);
        network_connections.push({
            id: __PROTOTYPE__TASK3_USER_ID,
            connectedDate: new Date()
        });
        selfUser.friends.push(__PROTOTYPE__TASK3_USER_ID);
        GlobalEvents.emit("connectionchange", {
            added: new Set([__PROTOTYPE__TASK3_USER_ID]),
            removed: new Set()
        });
    }, 6000);
}
const __PROTOTYPE__cancelRequestToEkin = () => {
    clearInterval(__PROTOTYPE__ekinRequestInterval);
}