/**
 * Calculates distance between two points. Copied from this StackOverflow answer:
 * https://stackoverflow.com/a/21623206/6212261.
 * @param {import("expo-location").LocationObjectCoords} coords1 The first set of coordinates.
 * @param {import("expo-location").LocationObjectCoords} coords2 The second set of coordinates.
 * @param {"km"|"kilometers"|"mi"|"miles"|"m"|"meters"|"ft"|"feet"} units The unit to return the
 *      distance in. Default is "km".
 */
const distanceBetweenPoints = function(coords1, coords2, units) {
    // Assign "km" to units by default.
    if (arguments.length == 2) {
        units = "km";
    }

    if (!(units in unitScale)) {
        throw new Error(`The provided units (${units}) must be one of: ${Object.values(unitScale).join(", ")}.`);
    }

    const EARTH_RADIUS = 6371; // in km
    const TO_RADS = Math.PI / 180;
    const value = 0.5 - Math.cos((coords2.latitude - coords1.latitude) * TO_RADS) / 2 +
        Math.cos(coords1.latitude * TO_RADS) * Math.cos(coords2.latitude * TO_RADS) *
        (1 - Math.cos((coords2.longitude - coords1.longitude) * TO_RADS)) / 2;

    return 2 * EARTH_RADIUS * Math.asin(Math.sqrt(value)) * unitScale[units];
};

const unitScale = {
    km: 1,
    kilometers: 0,
    mi: 0.6213711922,
    miles: 0.6213711922,
    m: 1000,
    meters: 1000,
    ft: 3280.839895,
    feet: 3280.839895
};

export default distanceBetweenPoints;