import * as Location from "expo-location";

/**
 * Returns the current location of the current user. On the real app, this would be asynchronously
 * retrieved using the `expo-location` API, but for now, it's just hard coded for the d.school
 * building.
 * @returns {import("expo-location").LocationObject} The user's current location.
 */
const getSelfLocation = () => {
    return {
        coords: {
            latitude: 37.42629334178031,
            longitude: -122.17176953327272
        }
    }
};

/**
 * Returns a promise that resolves to a boolean indicating whether we have permission to get the
 * location of the user. If we don't, and we're able to ask again, the user is asked to give their
 * permission.
 * @param {boolean} background Whether we need permission for getting the background location too.
 * @returns {Promise<boolean>}
 */
export const ensureLocationPermission = (background) => {
    return new Promise((resolve, reject) => {
        const foregroundOrBackGround = background ? "Background" : "Foreground";
        Location[`get${foregroundOrBackGround}PermissionsAsync`]().then(
            permissions => {
                if (permissions.granted) {
                    resolve(true);
                } else if (permissions.canAskAgain) {
                    Location[`request${foregroundOrBackGround}PermissionsAsync`]().then(
                        response => {
                            resolve(response.granted);
                        },
                        reject
                    );
                } else {
                    resolve(false);
                }
            },
            reject
        )
    })
}

export default getSelfLocation;