/**
 * @typedef {object} User
 * @property {String} firstName The user's first name.
 * @property {String} lastName The user's last name.
 * @property {String} profileImage A URL to the user's profile image.
 * @property {UserID} id The user's unique ID.
 * @property {Date} [creationDate] The date the user's account was created.
 * @property {Date} [birthDate] The user's birth date.
 * @property {Array<UserID>} friends A list of friends this user is friends with.
 */

/**
 * @typedef {number} UserID
 */

/**
 * @typedef {object} Connection
 * @property {UserID} id The ID of the user this connection is for.
 * @property {Date} connectedDate The timestamp when this connection was made.
 */

/**
 * @typedef {object} Message
 * @property {UserID} senderId The ID of the sender of this message.
 * @property {Number} type The type of message this is. For now, only `1` is used, which corresponds
 *      to a textual message.
 * @property {String} content The message's content. For now, this will always be a string since
 *      every message is a textual message.
 */

/**
 * @typedef {object} Interest
 * @property {Number} id The interest's unique ID.
 * @property {String} name The name of the interest.
 * @property {String} imageUrl The URL of the image to display for this interest.
 */

const now = new Date();

/** @type User */
export let selfUser = {
    firstName: "Enok",
    lastName: "Choe",
    profileImage: "https://lh6.googleusercontent.com/3cpwEssHBP_aRPLLspwvia_YyvwMWXqfibG5OOy2IUylryXyxUQbMg9ueG2XGEtw8FodeREGs7Wx1qjtP4Q2R3gCOi7uy2DiACyN7dj0phf3-fDQNXRabw8KNILl3DvvRgu3Icptf9Ii",
    creationDate: new Date("July 16, 2019"),
    pronouns: "He/Him",
    id: 0,
    friends: [-2,-1,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23],
    interests: ['academics', 'apple', 'art', 'basketball', 'classics', 'computer', 'dog', 'figma', 'music', 'praying', 'react', 'soccer', 'stanford', 'tennis', 'travel', 'volleyball', 'zebra'],
    isActive: true,
};

export const __PROTOTYPE__TASK3_USER_ID = -4;
export const __PROTOTYPE__TASK2_USER_ID = -3;

/** @type {{ [key: UserID]: User }} */
export const user_pool = {
    [-4]: {
        firstName: "Ekin",
        lastName: "Tiu",
        profileImage: "https://lh5.googleusercontent.com/H2lC-7BaTcawxgTpIw028ucldLzWo_jgjV1YkHH6Se64OKgHKMPH2WO5ymeIxDVGpsL5spy5GwtOmDzOFkYPeLozE95I-HendVcKnzS_HrqHj5d_hsFT6qQ2sFPit8C-z5Udl0-pE9UJ",
        id: -4,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 20.5),
        // birthDate: new Date("February 25, 2021"),
        pronouns: "He/Him",
        friends: [-3,-2,-1,5,9,17,19,24]
    },
    [-3]: {
        firstName: "Emily",
        lastName: "Hsu",
        profileImage: "https://lh3.googleusercontent.com/aeZn9qFjUZKrcoP2P5A3d6dmLgotVJfcKcOvTYUths16OxcRA7Mi1b2e1Bgb6u2pkYHgr-GIjBtLFa3gzTG-4279-mCC93F72unZNOykWR2fXI1gcu3bFwKdyjDvD1O76UWQxUBRBv7z",
        creationDate: new Date("May 16, 2020"),
        id: -3,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 21.5),
        pronouns: 'She/Her',
        friends: [-4,7, 11, 15, 21, 22],
        interests: ['academics', 'apple', 'art', 'basketball', 'classics', 'computer', 'dog', 'figma', 'music', 'praying', 'react', 'soccer', 'stanford', 'tennis', 'travel', 'volleyball', 'zebra']
    },
    [-2]: {
        firstName: "James",
        lastName: "Landay",
        profileImage: "https://ca.slack-edge.com/E7SAV7LAD-WA05SR9HT-d4628eeaf4f4-512",
        id: -2,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 21.5),
        pronouns: "He/Him",
        friends: [0,-1,7,11,22,29,34]
    },
    [-1]: {
        firstName: "Morgan",
        lastName: "Zagerman",
        profileImage: "https://ca.slack-edge.com/E7SAV7LAD-W011QCYV36D-b43cacc7d383-512",
        id: -1,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 21.5),
        pronouns: "She/Her",
        friends: [-2,0,5,8,12,16,25]
    },
    0: selfUser,
    1: {
        firstName: "John",
        lastName: "Doe",
        profileImage: "https://images.unsplash.com/photo-1599834562135-b6fc90e642ca?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=774&q=80",
        id: 1,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 29.5),
        pronouns: "He/Him",
        friends: [0,2,3,6,7,17,22,33]
    },
    2: {
        firstName: "Laylah",
        lastName: "Povey",
        profileImage: "https://images.unsplash.com/photo-1438761681033-6461ffad8d80?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MXx8cGVyc29ufGVufDB8fDB8fA%3D%3D&auto=format&fit=crop&w=500&q=60",
        id: 2,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 28.5),
        pronouns: "She/Her",
        friends: [0,1,3,6,17,23]
    },
    3: {
        firstName: "Mariyah",
        lastName: "Healy",
        profileImage: "https://images.unsplash.com/photo-1554151228-14d9def656e4?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8Nnx8cGVyc29ufGVufDB8fDB8fA%3D%3D&auto=format&fit=crop&w=500&q=60",
        id: 3,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 22.5),
        pronouns: "She/Her",
        friends: [0,1,2,5,10,16,19]
    },
    4: {
        firstName: "Mehreen",
        lastName: "Handley",
        profileImage: "https://images.unsplash.com/photo-1544005313-94ddf0286df2?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8M3x8cGVyc29ufGVufDB8fDB8fA%3D%3D&auto=format&fit=crop&w=500&q=60",
        id: 4,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 23.5),
        pronouns: "She/Her",
        friends: [0,5,10,12,21,27,29,30]
    },
    5: {
        firstName: "Rizwan",
        lastName: "Morton",
        profileImage: "https://images.unsplash.com/flagged/photo-1570612861542-284f4c12e75f?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8Mnx8cGVyc29ufGVufDB8fDB8fA%3D%3D&auto=format&fit=crop&w=500&q=60",
        id: 5,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 28.5),
        pronouns: "He/Him",
        friends: [-4,-1,0,3,4,8,10,30,31]
    },
    6: {
        firstName: "Kai",
        lastName: "Martinez",
        profileImage: "https://images.unsplash.com/photo-1547425260-76bcadfb4f2c?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8NHx8cGVyc29ufGVufDB8fDB8fA%3D%3D&auto=format&fit=crop&w=500&q=60",
        id: 6,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 24.5),
        pronouns: "He/Him",
        friends: [0,1,2,9,14,26,35]
    },
    7: {
        firstName: "Abbey",
        lastName: "Jacobson",
        profileImage: "https://images.unsplash.com/photo-1491349174775-aaafddd81942?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8OHx8cGVyc29ufGVufDB8fDB8fA%3D%3D&auto=format&fit=crop&w=500&q=60",
        id: 7,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 23.5),
        pronouns: "She/Her",
        friends: [-3,-2,0,1,10,16,22,31]
    },
    8: {
        firstName: "Kiri",
        lastName: "Murray",
        profileImage: "https://images.unsplash.com/photo-1500048993953-d23a436266cf?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MTJ8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 8,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 21.5),
        pronouns: "He/They",
        friends: [-1,0,5,20,21,34,37]
    },
    9: {
        firstName: "Indiana",
        lastName: "Ortega",
        profileImage: "https://images.unsplash.com/photo-1599566150163-29194dcaad36?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MTZ8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 9,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 26.5),
        pronouns: "He/Him",
        friends: [-4,0,6,7,13,15,24,28,34,35],
    },
    10: {
        firstName: "Katelyn",
        lastName: "Meyer",
        profileImage: "https://images.unsplash.com/photo-1580489944761-15a19d654956?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MTd8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 10,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 25.5),
        pronouns: "She/Her",
        friends: [0,3,4,5,7,11,19,20,25]
    },
    11: {
        firstName: "Ethan",
        lastName: "Kim",
        profileImage: "https://images.unsplash.com/photo-1545167622-3a6ac756afa4?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8NTd8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 11,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 37.5),
        pronouns: "He/Him",
        friends: [-3,-2,0,10,13,22,24,25,30]
    },
    12: {
        firstName: "Richard",
        lastName: "Knowles",
        profileImage: "https://images.unsplash.com/photo-1531427186611-ecfd6d936c79?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MTl8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 12,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 21.5),
        pronouns: "He/Him",
        friends: [-1,0,4,13,17,18,23,24,30,31]
    },
    13: {
        firstName: "Catrina",
        lastName: "Bassett",
        profileImage: "https://images.unsplash.com/photo-1573140247632-f8fd74997d5c?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8Mjd8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 13,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 26.5),
        pronouns: "She/Her",
        friends: [0,9,11,12,24,26,27,30]
    },
    14: {
        firstName: "Kimberly",
        lastName: "Herman",
        profileImage: "https://images.unsplash.com/photo-1593104547489-5cfb3839a3b5?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MjJ8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 14,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 25.5),
        pronouns: "She/Her",
        friends: [0,6,18,23,35,36,37]
    },
    15: {
        firstName: "Joanna",
        lastName: "Burch",
        profileImage: "https://images.unsplash.com/photo-1542206395-9feb3edaa68d?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MjV8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 15,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 25.5),
        pronouns: "She/Her",
        friends: [-3,0,9,19,23,32,33,37]
    },
    16: {
        firstName: "Teri",
        lastName: "Merritt",
        profileImage: "https://images.unsplash.com/photo-1503249023995-51b0f3778ccf?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MjF8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 16,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 29.5),
        pronouns: "He/Him",
        friends: [-1,0,3,7,19,20,35]
    },
    17: {
        firstName: "Justin",
        lastName: "McCarthy",
        profileImage: "https://images.unsplash.com/photo-1500648767791-00dcc994a43e?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8Mjh8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 17,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 30.5),
        pronouns: "He/Him",
        friends: [-4,0,1,2,12,25,27,32]
    },
    18: {
        firstName: "Etta",
        lastName: "Manning",
        profileImage: "https://images.unsplash.com/photo-1494790108377-be9c29b29330?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MzB8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 18,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 29.5),
        pronouns: "She/Her",
        friends: [0,12,14,19,23,29,32,36]
    },
    19: {
        firstName: "Libby",
        lastName: "Hartley",
        profileImage: "https://images.unsplash.com/photo-1554727242-741c14fa561c?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MzR8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 19,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 28.5),
        pronouns: "She/Her",
        friends: [-4,0,3,10,15,16,18,22,28,33]
    },
    20: {
        firstName: "Eileen",
        lastName: "Barclay",
        profileImage: "https://images.unsplash.com/photo-1534528741775-53994a69daeb?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8NDB8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 20,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 29.5),
        pronouns: "She/Her",
        friends: [0,8,10,16,26,28,31]
    },
    21: {
        firstName: "Lee",
        lastName: "Smith",
        profileImage: "https://images.unsplash.com/photo-1544723795-3fb6469f5b39?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MzJ8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 21,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 33.5),
        pronouns: "He/Him",
        friends: [-3,0,4,8,26,27,31]
    },
    22: {
        firstName: "Trystan",
        lastName: "Donald",
        profileImage: "https://images.unsplash.com/photo-1568602471122-7832951cc4c5?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MzV8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 22,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 28.5),
        pronouns: "He/Him",
        friends: [-3,-2,0,1,7,11,19,28]
    },
    23: {
        firstName: "Saba",
        lastName: "Macdonald",
        profileImage: "https://images.unsplash.com/photo-1584362562886-9b9002d5e493?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=687&q=80",
        id: 23,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 34.5),
        pronouns: "They/Them",
        friends: [0,2,12,14,15,18,29,34,35]
    },
    24: {
        firstName: "Iqrah",
        lastName: "Lin",
        profileImage: "https://images.unsplash.com/photo-1521119989659-a83eee488004?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8NDN8fHBlcnNvbnxlbnwwfHwwfHw%3D&auto=format&fit=crop&w=500&q=60",
        id: 24,
        friends: [-4,0,9,11,12,13,26,32,37]
    },
    25: {
        firstName: "Ashraf",
        lastName: "Watkins",
        profileImage: "",
        id: 25,
        birthDate: now,
        friends: [-1,0,10,11,17,28]
    },
    26: {
        firstName: "Clifford",
        lastName: "Weston",
        profileImage: "",
        id: 26,
        birthDate: now,
        friends: [0,6,13,20,21,24,29]
    },
    27: {
        firstName: "Shahzaib",
        lastName: "Holden",
        profileImage: "",
        id: 27,
        birthDate: now,
        friends: [0,4,13,17,21,30,34]
    },
    28: {
        firstName: "Vernon",
        lastName: "Suarez",
        profileImage: "",
        id: 28,
        birthDate: now,
        friends: [0,9,19,20,22,25,32,36]
    },
    29: {
        firstName: "Sarah",
        lastName: "Vaughan",
        profileImage: "https://images.unsplash.com/photo-1525134479668-1bee5c7c6845?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=687&q=80",
        id: 29,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 26.5),
        pronouns: "She/Her",
        friends: [-2,4,18,23,26]
    },
    30: {
        firstName: "Ruth",
        lastName: "Prosser",
        profileImage: "https://images.unsplash.com/photo-1496361001419-80f0d1be777a?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=687&q=80",
        id: 30,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 23.5),
        pronouns: "She/Her",
        friends: [3,5,10,11,13,27,32]
    },
    31: {
        firstName: "Joseph",
        lastName: "Gonzalez",
        profileImage: "https://images.unsplash.com/photo-1507003211169-0a1dd7228f2d?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=687&q=80",
        id: 31,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 23.5),
        pronouns: "He/Him",
        friends: [5,7,12,20,21,33,36]
    },
    32: {
        firstName: "Isaac",
        lastName: "Khan",
        profileImage: "https://images.unsplash.com/photo-1539571696357-5a69c17a67c6?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=687&q=80",
        id: 32,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 26.5),
        pronouns: "He/Him",
        friends: [15,17,18,24,28,30]
    },
    33: {
        firstName: "Peter",
        lastName: "Dyer",
        profileImage: "https://images.unsplash.com/photo-1506794778202-cad84cf45f1d?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=687&q=80",
        id: 33,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 26.5),
        pronouns: "He/Him",
        friends: [1,15,19,23,31]
    },
    34: {
        firstName: "John",
        lastName: "Farley",
        profileImage: "https://images.unsplash.com/photo-1489980557514-251d61e3eeb6?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=1770&q=80",
        id: 34,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 29.5),
        pronouns: "He/Him",
        friends: [-2,8,9,23,27,37]
    },
    35: {
        firstName: "Jacob",
        lastName: "Howard",
        profileImage: "https://images.unsplash.com/photo-1492562080023-ab3db95bfbce?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=1448&q=80",
        id: 35,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 32.5),
        pronouns: "He/Him",
        friends: [6,9,14,16,23,36]
    },
    36: {
        firstName: "Anna",
        lastName: "Larsen",
        profileImage: "https://images.unsplash.com/photo-1517841905240-472988babdf9?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=687&q=80",
        id: 36,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 26.5),
        pronouns: "She/Her",
        friends: [14,18,28,31,35]
    },
    37: {
        firstName: "Aaron",
        lastName: "Edmonds",
        profileImage: "https://images.unsplash.com/photo-1463453091185-61582044d556?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=1770&q=80",
        id: 37,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 28.5),
        pronouns: "He/Him",
        friends: [8,14,15,24,34]
    },
    38: {
        firstName: "Annalise",
        lastName: "Chang",
        profileImage: "https://images.unsplash.com/photo-1583284791098-29f95de7190b?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=676&q=80",
        id: 38,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 30.5),
        pronouns: "She/Her",
        friends: [5,10,12,21,27,29,30]
    },
    39: {
        firstName: "Annabel",
        lastName: "McKee",
        profileImage: "https://images.unsplash.com/photo-1595085610896-fb31cfd5d4b7?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=867&q=80",
        id: 39,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 20.5),
        pronouns: "She/Her",
        friends: [5,10,12,21,27,29,30]
    },
    40: {
        firstName: "Emma",
        lastName: "Smith",
        profileImage: "https://images.unsplash.com/photo-1544725176-7c40e5a71c5e?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8OTJ8fHByb2ZpbGV8ZW58MHx8MHx8&auto=format&fit=crop&w=500&q=60",
        id: 40,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 23.5),
        pronouns: "She/Her",
        friends: [0,5,10,12,21,27,29,30]
    },
    41: {
        firstName: "Roger",
        lastName: "Federer",
        profileImage: "https://cdn.britannica.com/57/183257-050-0BA11B4B/Roger-Federer-2012.jpg",
        id: 41,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 40.5),
        pronouns: "He/Him",
        friends: [0,5,10,12,21,27,29,30]
    },
    42: {
        firstName: "Sannah",
        lastName: "Rogers",
        profileImage: "https://images.unsplash.com/photo-1532074205216-d0e1f4b87368?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=441&q=80",
        id: 42,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 26.5),
        pronouns: "She/Her",
        friends: [0,5,10,12,21,27,29,30]
    },
    43: {
        firstName: "Drew",
        lastName: "Hayes",
        profileImage: "https://images.unsplash.com/photo-1480455624313-e29b44bbfde1?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxzZWFyY2h8MTI3fHxwcm9maWxlfGVufDB8fDB8fA%3D%3D&auto=format&fit=crop&w=500&q=60",
        id: 43,
        birthDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 365 * 37.5),
        pronouns: "He/Him",
        friends: [5,10,12,21,27,29,30]
    }
};

/** @type {{ [key: UserID]: Number }} */
export const matchScores = {
    [-4]: 0.99,
    [-3]: 0.95,
    [-2]: 0.87,
    [-1]: 1.00,
    1: 0.74,
    2: 0.61,
    3: 0.91,
    4: 0.83,
    5: 0.98,
    6: 0.67,
    7: 0.59,
    8: 0.82,
    9: 0.82,
    10: 0.95,
    11: 0.68,
    12: 0.77,
    13: 0.79,
    14: 0.88,
    15: 0.64,
    16: 0.82,
    17: 0.97,
    18: 0.68,
    19: 0.91,
    20: 0.68,
    21: 0.84,
    22: 0.88,
    23: 0.72,
    24: 0.65,
    25: 0.90,
    26: 0.79,
    27: 0.83,
    28: 0.69,
    29: 0.96,
    30: 0.89,
    31: 0.80,
    32: 0.74,
    33: 0.71,
    34: 0.65,
    35: 0.59,
    36: 0.48,
    37: 0.41,
    38: 0.82,
    39: 0.83,
    40: 0.84,
    41: 0.99,
    42: 0.87,
    43: 0.80,
};

/**
 * @param {UserID} ID
 * @returns {Array<Message>}
 */
const genericMessages = (ID) => {
    return [
        {
            senderId: ID,
            type: 1,
            content: `Hi, I'm ${user_pool[ID].firstName}!`
        },
        {
            senderId: ID,
            type: 1,
            content: `This is a generic message. Feel free to type your own message to me.`
        },
        {
            senderId: selfUser.id,
            type: 1,
            content: `Hi ${user_pool[ID].firstName}, I'm ${selfUser.firstName}!`
        },
        {
            senderId: selfUser.id,
            type: 1,
            content: "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua."
        }
    ];
}

/**
 * @type {{ [key: UserID]: Array<Message> }}
 */
export const messages_objects = {
    [-4]: genericMessages(-4),
    [-3]: genericMessages(-3),
    [-2]: genericMessages(-2),
    [-1]: genericMessages(-1),
    1: genericMessages(1),
    2: genericMessages(2),
    3: genericMessages(3),
    4: genericMessages(4),
    5: genericMessages(5),
    6: genericMessages(6),
    7: genericMessages(7),
    8: genericMessages(8),
    9: genericMessages(9),
    10: genericMessages(10),
    11: genericMessages(11),
    12: genericMessages(12),
    13: genericMessages(13),
    14: genericMessages(14),
    15: genericMessages(15),
    16: genericMessages(16),
    17: genericMessages(17),
    18: genericMessages(18),
    19: genericMessages(19),
    20: genericMessages(20),
    21: genericMessages(21),
    22: genericMessages(22),
    23: genericMessages(23),
    24: genericMessages(24),
    25: genericMessages(25),
    26: genericMessages(26),
    27: genericMessages(27),
    28: genericMessages(28),
    29: [
        {
            senderId: selfUser.id,
            type: 1,
            content: `Hi ${user_pool[29].firstName}! This is ${selfUser.firstName}. May I add you as my friend?`
        },
        {
            senderId: selfUser.id,
            type: 1,
            content: "I saw that you are also into cooking, and I would love to talk about it with you!"
        },
        {
            senderId: 29,
            type: 1,
            content: "Absolutely!"
        },
    ],
    30: [],
    31: [],
    32: [],
    33: [],
    34: [],
    35: [],
    36: [],
    37: [],
    38: [],
    39: [],
    40: [],
    41: [],
    42: [],
    43: [],
    [__PROTOTYPE__TASK2_USER_ID]: [
        {
            senderId: __PROTOTYPE__TASK2_USER_ID,
            type: 1,
            content: `Hi, I'm ${user_pool[__PROTOTYPE__TASK2_USER_ID].firstName}! Do you want to meet up in person?`
        },
        {
            senderId: selfUser.id,
            type: 1,
            content: "Sure!"
        },
        {
            senderId: __PROTOTYPE__TASK2_USER_ID,
            type: 1,
            content: `Share your location so we can find each other.`
        },
    ],
    [__PROTOTYPE__TASK3_USER_ID]: [
        {
            senderId: selfUser.id,
            type: 1,
            content: `Hi ${user_pool[__PROTOTYPE__TASK3_USER_ID].firstName}!`
        },
        {
            senderId: selfUser.id,
            type: 1,
            content: "Cool to see you're on Collide!"
        },
        {
            senderId: __PROTOTYPE__TASK3_USER_ID,
            type: 1,
            content: `Hi ${selfUser.firstName}!`
        },
        {
            senderId: __PROTOTYPE__TASK3_USER_ID,
            type: 1,
            content: "Yeah, I just downloaded it! It has such a good UI and the four people who made it definitely deserve an A+ in the class :)"
        }
    ]
};

/** @type {Set<UserID>} */
export const networkRequestsSent = new Set();

/** @type {{ [key: UserID]: import("expo-location").LocationObject }} */
export const approximateLocations = {
    [-4]: {
        coords: {
            latitude: 0,
            longitude: 0
        }
    },
    [-3]: {
        coords: {
            latitude: 37.426797710394716,
            longitude: -122.17176942816346
        }
    },
    29: {
        // White Plaza fountain
        coords: {
            latitude: 37.425003,
            longitude: -122.169267
        }
    },
    30: {
        // Near TAP
        coords: {
            latitude: 37.425015,
            longitude: -122.170384
        }
    },
    31: {
        // Engineering Quad
        coords: {
            latitude: 37.428178572868745,
            longitude: -122.17353982674126
        }
    },
    32: {
        // Building 50 in Main Quad
        coords: {
            latitude: 37.42700377674781,
            longitude: -122.16984176839277
        }
    },
    33: {
        // Lakeside
        coords: {
            latitude: 37.42466205638118,
            longitude: -122.17637837419696
        }
    },
    34: {
        // Roble B Wing,
        coords: {
            latitude: 37.42435713840595,
            longitude: -122.1747546237569
        }
    },
    35: {
        // Memorial Church
        coords: {
            latitude: 37.42684224230076,
            longitude: -122.17045971410339
        }
    },
    36: {
        // Coupa Cafe near Meyer Green
        coords: {
            latitude: 37.42622826312597,
            longitude: -122.16698955885872
        }
    },
    37: {
        // Random spot in the oval
        coords: {
            latitude: 37.42929132335568,
            longitude: -122.1693252174824
        }
    }
}

/** @type {Array<Connection>} */
export const network_connections = [
    {
        id: -2,
        connectedDate: new Date(now.valueOf() - 1000 * 60 * 27) // 27 mins ago
    },
    {
        id: -1,
        connectedDate: new Date(now.valueOf() - 1000 * 60 * 60 * 12) // 12 hours ago
    },
    {
        id: 1,
        connectedDate: new Date(now.valueOf() - 1000 * 60 * 60 * 18) // 18 hours ago
    },
    {
        id: 2,
        connectedDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 1.5) // 1.5 days ago
    },
    {
        id: 3,
        connectedDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 4) // 4 days ago
    },
    {
        id: 4,
        connectedDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 18) // 18 days ago
    },
    {
        id: 5,
        connectedDate: new Date(now.valueOf() - 1000 * 60 * 60 * 24 * 20) // 20 days ago
    },
    {
        id: 6,
        connectedDate: new Date("February 1, 2022")
    },
    {
        id: 7,
        connectedDate: new Date("January 25, 2022")
    },
    {
        id: 8,
        connectedDate: new Date("January 23, 2022")
    },
    {
        id: 9,
        connectedDate: new Date("January 20, 2022")
    },
    {
        id: 10,
        connectedDate: new Date("January 15, 2022")
    },
    {
        id: 11,
        connectedDate: new Date("January 11, 2022")
    },
    {
        id: 12,
        connectedDate: new Date("January 1, 2022")
    },
    {
        id: 13,
        connectedDate: new Date("December 16, 2021")
    },
    {
        id: 14,
        connectedDate: new Date("December 10, 2021")
    },
    {
        id: 15,
        connectedDate: new Date("December 3, 2021")
    },
    {
        id: 16,
        connectedDate: new Date("November 29, 2021")
    },
    {
        id: 17,
        connectedDate: new Date("November 23, 2021")
    },
    {
        id: 18,
        connectedDate: new Date("November 15, 2021")
    },
    {
        id: 19,
        connectedDate: new Date("November 8, 2021")
    },
    {
        id: 20,
        connectedDate: new Date("November 3, 2021")
    },
    {
        id: 21,
        connectedDate: new Date("October 31, 2021")
    },
    {
        id: 22,
        connectedDate: new Date("October 30, 2021")
    },
    {
        id: 23,
        connectedDate: new Date("October 26, 2021")
    }
];

// export const messagesWithEkin = [
//     {
//         senderId: selfUser.id,
//         type: 1,
//         content: "Hi Ekin!"
//     },
//     {
//         senderId: -4,
//         type: 1,
//         content: "Hi Enok!"
//     },
//     {
//         senderId: -4,
//         type: 1,
//         content: "Make sure to add me to your network first!"
//     }
// ]

/** @type Array<Interest> */
export const interestCategories = [
    {
        id: 1,
        name: 'academics',
        imageUrl: require("../assets/images/bubbles/academics.png"),
    },
    {
        id: 2,
        name: 'apple',
        imageUrl: require("../assets/images/bubbles/apple.png"),
    },
    {
        id: 3,
        name: 'art',
        imageUrl: require("../assets/images/bubbles/art.png"),
    },
   {
        id: 4,
        name: 'basketball',
        imageUrl: require("../assets/images/bubbles/basketball.png"),
    },
    {
        id: 5,
        name: 'classics',
        imageUrl: require("../assets/images/bubbles/classics.png"),
    },
    {
        id: 6,
        name: 'computer',
        imageUrl: require("../assets/images/bubbles/computer.png"),
    },
    {
        id: 7,
        name: 'dog',
        imageUrl: require("../assets/images/bubbles/dog.png"),
    },
    {
        id: 8,
        name: 'figma',
        imageUrl: require("../assets/images/bubbles/figma.png"),
    },
    {
        id: 9,
        name: 'music',
        imageUrl: require("../assets/images/bubbles/music.png"),
    },
    {
        id: 10,
        name: 'praying',
        imageUrl: require("../assets/images/bubbles/praying.png"),
    },
    {
        id: 11,
        name: 'react',
        imageUrl: require("../assets/images/bubbles/react.png"),
    },
    {
        id: 12,
        name: 'soccer',
        imageUrl: require("../assets/images/bubbles/soccer.png"),
    },
    {
        id: 13,
        name: 'stanford',
        imageUrl: require("../assets/images/bubbles/stanford.png"),
    },
    {
        id: 14,
        name: 'tennis',
        imageUrl: require("../assets/images/bubbles/tennis.png"),
    },
    {
        id: 15,
        name: 'travel',
        imageUrl: require("../assets/images/bubbles/travel.png"),
    },
    {
        id: 16,
        name: 'volleyball',
        imageUrl: require("../assets/images/bubbles/volleyball.png"),
    },
    {
        id: 17,
        name: 'zebra',
        imageUrl: require("../assets/images/bubbles/zebra.png"),
    },
];