/**
 * Produces a random number given a set of seeds. Passing in the same seeds will yield the same
 * random number each time. Based on this StackOverflow answer:
 * https://stackoverflow.com/a/47593316/6212261.
 * @param  {...(number|string)} seeds A list of seeds to use for generating the number.
 * @returns {number} A random number in the range [0, 1).
 */
 const seeded_rand = (...seeds) => {
    let seed = seeds.join(":");
    for(var i = 0, h = 1779033703 ^ seed.length; i < seed.length; i++) {
        h = Math.imul(h ^ seed.charCodeAt(i), 3432918353);
        h = h << 13 | h >>> 19;
    }
    h = Math.imul(h ^ (h >>> 16), 2246822507);
    h = Math.imul(h ^ (h >>> 13), 3266489909);
    seed = (h ^= h >>> 16) >>> 0;
    let t = seed += 0x6D2B79F5;
    t = Math.imul(t ^ t >>> 15, t | 1);
    t ^= t + Math.imul(t ^ t >>> 7, t | 61);
    return ((t ^ t >>> 14) >>> 0) / 4294967296;
};

export default seeded_rand;